@@ -1,12 +1,12 @@
 ## ----setup, include=FALSE, cache=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 options(width = 1000)
-knitr::opts_chunk$set(echo = TRUE, message = FALSE, warning = FALSE, comment = NA, eval = TRUE)
+knitr::opts_chunk$set(echo = TRUE, message = FALSE, warning = FALSE, comment = NA, eval = TRUE, fig.width = 5, fig.height = 5)
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(udpipe)
 ud_model <- udpipe_download_model(language = "spanish")
 
-## ---- echo=FALSE----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ----echo=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE, message = FALSE, warning = FALSE, comment = NA, eval = !ud_model$download_failed)
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -73,33 +73,33 @@ cooc <- cooccurrence(x = subset(x, upos %in% c("NOUN", "ADJ")),
 head(cooc)
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  library(igraph)
-#  library(ggraph)
-#  library(ggplot2)
-#  wordnetwork <- head(cooc, 30)
-#  wordnetwork <- graph_from_data_frame(wordnetwork)
-#  ggraph(wordnetwork, layout = "fr") +
-#    geom_edge_link(aes(width = cooc, edge_alpha = cooc), edge_colour = "pink") +
-#    geom_node_text(aes(label = name), col = "darkgreen", size = 4) +
-#    theme_graph(base_family = "Arial Narrow") +
-#    theme(legend.position = "none") +
-#    labs(title = "Cooccurrences within sentence", subtitle = "Nouns & Adjective")
+# library(igraph)
+# library(ggraph)
+# library(ggplot2)
+# wordnetwork <- head(cooc, 30)
+# wordnetwork <- graph_from_data_frame(wordnetwork)
+# ggraph(wordnetwork, layout = "fr") +
+#   geom_edge_link(aes(width = cooc, edge_alpha = cooc), edge_colour = "pink") +
+#   geom_node_text(aes(label = name), col = "darkgreen", size = 4) +
+#   theme_graph(base_family = "Arial Narrow") +
+#   theme(legend.position = "none") +
+#   labs(title = "Cooccurrences within sentence", subtitle = "Nouns & Adjective")
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 cooc <- cooccurrence(x$lemma, relevant = x$upos %in% c("NOUN", "ADJ"), skipgram = 1)
 head(cooc)
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  library(igraph)
-#  library(ggraph)
-#  library(ggplot2)
-#  wordnetwork <- head(cooc, 15)
-#  wordnetwork <- graph_from_data_frame(wordnetwork)
-#  ggraph(wordnetwork, layout = "fr") +
-#    geom_edge_link(aes(width = cooc, edge_alpha = cooc)) +
-#    geom_node_text(aes(label = name), col = "darkgreen", size = 4) +
-#    theme_graph(base_family = "Arial Narrow") +
-#    labs(title = "Words following one another", subtitle = "Nouns & Adjective")
+# library(igraph)
+# library(ggraph)
+# library(ggplot2)
+# wordnetwork <- head(cooc, 15)
+# wordnetwork <- graph_from_data_frame(wordnetwork)
+# ggraph(wordnetwork, layout = "fr") +
+#   geom_edge_link(aes(width = cooc, edge_alpha = cooc)) +
+#   geom_node_text(aes(label = name), col = "darkgreen", size = 4) +
+#   theme_graph(base_family = "Arial Narrow") +
+#   labs(title = "Words following one another", subtitle = "Nouns & Adjective")
 
 ## -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 x$id <- unique_identifier(x, fields = c("sentence_id", "doc_id"))
@@ -113,6 +113,6 @@ y <- subset(y, term1 < term2 & abs(cooc) > 0.2)
 y <- y[order(abs(y$cooc), decreasing = TRUE), ]
 head(y)
 
-## ---- results='hide', echo=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+## ----results='hide', echo=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 invisible(if(file.exists(ud_model$file)) file.remove(c(ud_model$file)))
 
